@@ -2,19 +2,25 @@ import datetime
 import pandas as pd
 import re
 import itertools
+import requests
+import json
 
-from .build_data_frame import build_data_frame
+from .build_data_frame import build_data_frame, prepare_df
 from .run_analysis import apply_logic_to_df
 from .build_summary import build_summary
 
 
+class MissingData(Exception):
+    pass
+
+
 def run_backtest(
-    backtest: dict, ohlcv_path: str = "", df: pd.DataFrame = None, summary=True
+    backtest: dict, data_path: str = "", df: pd.DataFrame = None, summary=True
 ):
     """
     Parameters
         backtest: dict, required, object containing the logic to test and other details
-        ohlcv_path: string or list, required, where to find the csv file of the ohlcv data
+        data_path: string or list, required, where to find the csv file of the ohlcv data
         df: pandas dataframe indexed by date
     Returns
         dict
@@ -25,8 +31,17 @@ def run_backtest(
 
     performance_start_time = datetime.datetime.utcnow()
     new_backtest = prepare_new_backtest(backtest)
-    if ohlcv_path:
-        df = build_data_frame(new_backtest, ohlcv_path)
+
+    reg = r"https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_\+.~#?&//=]*)"
+
+    is_url = re.search(reg, data_path)
+    if data_path:
+        if is_url:
+            # url
+            df = pd.read_csv(data_path)
+            df = prepare_df(df, new_backtest)
+        else:
+            df = build_data_frame(new_backtest, data_path)
 
     df = apply_backtest_to_df(df, new_backtest)
 
